*************
Citing COSMIC
*************

If you use COSMIC in your work, please cite both:

- The COSMIC release paper: `Breivik et al. 2020 <https://ui.adsabs.harvard.edu/abs/2019arXiv191100903B/abstract>`_
- The specific Zenodo DOI associated with version of COSMIC you used

We recommend using the `Software Citation Station <https://tomwagg.com/software-citation-station>`_ to generate a citation
for COSMIC (and any other software you use in your work!) - it's a great way to ensure you're citing software correctly and
offers a quick way to find the right Zenodo record for the version you're using.

.. raw:: html

    <div style="max-width: 400px; margin: 30px auto;">
        <div class="toms-nav-box" data-href="https://tomwagg.com/software-citation-station/?auto-select=COSMIC">Generate citation</div>
    </div>